@@ -3,8 +3,20 @@
  *********************************************************/
 
 #include "callbacks.h"
+#include "callback_func.h"
+#include "fixture.h"
+#include "free.h"
+#include "gui.h"
+#include "game_gui.h"
+#include "load_save.h"
+#include "maths.h"
+#include "misc.h"
+#include "player.h"
+#include "team.h"
+#include "treeview.h"
+#include "startup.h"
 #include "support.h"
-
+#include "window.h"
 
 /************************************************************
  * callbacks for the main window                            *
@@ -24,7 +36,9 @@ on_menu_new_activate                   (GtkMenuItem     *menuitem,
 	start(1);
     }
     else
-	show_popup_window("Are you sure you want to start a new game and discard your current game?", popup_status);    
+	show_popup_window(
+	    _("Are you sure you want to start a new game and discard your current game?"),
+	    popup_status);
 }
 
 
@@ -103,6 +117,7 @@ on_structure_entry_activate            (GtkEntry        *entry,
 {
     gint i;
     gint new_structure = entry_get_int(entry);
+    gchar buf[SMALL];
 
     if(new_structure == teams[my_team].structure)
 	return;
@@ -117,7 +132,7 @@ on_structure_entry_activate            (GtkEntry        *entry,
 	callback_rearrange(FALSE);
     }
     else
-	print_message("Your team structure must have three non-zero digits which sum up to 10.");
+	print_message(_("Your team structure must have three non-zero digits which sum up to 10."));
 
     entry_set_text_from_int(entry, teams[my_team].structure);    
 
@@ -125,19 +140,36 @@ on_structure_entry_activate            (GtkEntry        *entry,
     if(new_structure > -9 && new_structure < 0)
 	print_average_skill(new_structure * -1);
     else if(new_structure == -9)
-	g_print("\n *** Cntsuc: %d ***\n\n", 
-		counters[COUNT_SUCCESS]);
+    {
+	sprintf(buf, "Cntsuc: %d", counters[COUNT_SUCCESS]);
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
+    }
     else if(new_structure == -10)
-	options[OPT_ATT_TALENT] = (options[OPT_ATT_TALENT] + 1) % 2;
+    {
+	options[OPT_ATT_TALENT] = (options[OPT_ATT_TALENT] + 1) % 2;	
+	sprintf(buf, "Show talent %d", options[OPT_ATT_TALENT]);
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
+    }
     else if(new_structure == -11)
     {
 	finances[FIN_DEBTS] = 0;
 	counters[COUNT_LOAN] = -2;
+	sprintf(buf, "Debts reset; loan counter reset");
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
     }
     else if(new_structure == -12)
+    {
 	for(i=0;i<20;i++)
 	    teams[my_team].players[i].age =
 		teams[my_team].players[i].peak_age;
+
+	sprintf(buf, "Player ages set to peak age");
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
+    }
     else if(new_structure < -114 && new_structure > -175)
 	my_team = new_structure * -1;
     else if(new_structure < -70 && new_structure > -99)
@@ -152,15 +184,48 @@ on_structure_entry_activate            (GtkEntry        *entry,
 		    teams[transferlist[i].team_id].name);
     }
     else if(new_structure < -250 && new_structure > -300)
+    {
 	stadiums[my_team].capacity = (new_structure * -1) % 100 * 1000;
+	sprintf(buf, "New stadium capacity: %d", stadiums[my_team].capacity);
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
+    }
     else if(new_structure >= 50 && new_structure <= 99)
+    {
 	options[OPT_DUMMY1] = new_structure;
+	sprintf(buf, "Safety warning set to %d%%",
+		options[OPT_DUMMY1]);
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
+    }
     else if(new_structure == 100)
+    {
 	options[OPT_DUMMY1] *= -1;
+	sprintf(buf, "Safety warning %d",
+		(options[OPT_DUMMY1] > 0));
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
+    }
     else if(new_structure == 999)
     {
 	debug = (debug + 1) % 2;
-	g_print("\n *** Debug: %d ***\n\n", debug);
+	sprintf(buf, "Debug: %d", debug);
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
+    }
+    else if(new_structure == 900)
+    {
+	counters[COUNT_SUCCESS] += 50;
+	sprintf(buf, "Added 50 to success counter. New value: %d", counters[COUNT_SUCCESS]);
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
+    }
+    else if(new_structure == 899)
+    {
+	counters[COUNT_SUCCESS] -= 50;
+	sprintf(buf, "Substracted 50 from success counter. New value: %d", counters[COUNT_SUCCESS]);
+	g_print("\n *** %s ***\n\n", buf);
+	print_message(buf);
     }
 }
 
@@ -175,7 +240,7 @@ on_scout_optionmenu_changed            (GtkOptionMenu   *optionmenu,
 	set_save(FALSE);
 	scout = scout % 10 + (new_scout * 10);
 	print_message(
-	    "Next week you'll fire your scout and hire a new one.");
+	    _("Next week you'll fire your scout and hire a new one."));
     }
     else
 	scout = scout % 10;
@@ -257,7 +322,11 @@ on_button_transfers_clicked           (GtkButton       *button,
 {
     show_transfers();
     status = 100000;
-    notify_status = FALSE;
+    notify_status[NOTIFY_TRANSFERS] = FALSE;
+
+    gtk_notebook_set_current_page(
+	GTK_NOTEBOOK(lookup_widget(main_window, "notebook_player")), 1);
+
     set_buttons();
 }
 
@@ -269,21 +338,43 @@ on_player_info_button_press_event      (GtkWidget       *widget,
 {
     GtkTreeSelection *selection = 
 	gtk_tree_view_get_selection(GTK_TREE_VIEW(widget));
-
+    gint row_idx = 
+	get_row_index(selection, event, (get_place(status, 12) == 22));
+    gint id;
+    
     if(event->type == GDK_BUTTON_PRESS)
     {
-	if(status == 0)
-	    callback_show_opponent_team(selection, event);
+	if(status == 0 && row_idx >= 0)
+	{
+	    status = 130000 + row_idx;
+	    show_team_browse(row_idx, NULL);
+	}
 	else if(get_place(status, 12) == 10 ||
 	   get_place(status, 12) == 11)
 	{
-	    if(callback_transfer_select(selection, event) == 1)
+	    if(callback_transfer_select(row_idx - 1))
 		status = 110000 + get_place(status, 22);
 	}
 	else if(status == 120000)
-	    callback_transfer_team_select(selection, event);   
+	    callback_transfer_team_select(row_idx - 1);
 	else if(get_place(status, 12) == 13)
-	    callback_transfer_buy_player(selection, event);
+	    callback_transfer_buy_player(row_idx - 1);
+	else if(get_place(status, 12) == 22 && row_idx != my_team &&
+		row_idx >= 0 && row_idx < 130)
+	{
+	    id = teams[row_idx].id;
+	    status = 130000 + id;
+	    show_team_browse(id, NULL);
+	}
+	else if(get_place(status, 12) == 21 &&
+		row_idx >= 0 && row_idx < FIX_END)
+	{
+	    id = fixtures[row_idx].team_id[(event->button == 3)];
+	    if(id == my_team)
+		id = fixtures[row_idx].team_id[(event->button != 3)];
+	    status = 130000 + id;
+	    show_team_browse(id, NULL);
+	}
     }
 
     set_buttons();
@@ -292,6 +383,19 @@ on_player_info_button_press_event      (GtkWidget       *widget,
 }
 
 
+gboolean
+on_player_list2_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data)
+{
+    on_player_list_button_press_event(
+	lookup_widget(main_window, "player_list"),
+	event, NULL);
+
+  return FALSE;
+}
+
+
 void
 on_button_transfer_ok_clicked          (GtkButton       *button,
                                         gpointer         user_data)
@@ -351,9 +455,7 @@ void
 on_button_browse_back_clicked          (GtkButton       *button,
                                         gpointer         user_data)
 {
-    if(!GTK_WIDGET_MAPPED(button))
-	on_button_quit_clicked(button, NULL);
-    else if(get_place(status, 12) == 13)
+    if(get_place(status, 12) == 13)
 	callback_transfers_browse_teams(-1);
     else if(get_place(status, 12) == 21)
     {	
@@ -420,17 +522,23 @@ on_button_back_to_main_clicked         (GtkButton       *button,
 {
     gint popup_status[3] = {0, -1, -1};
 
+    if(notify_status[NOTIFY_TRANSFERS])
+    {	
+	notify_status[NOTIFY_TRANSFERS] = FALSE;
+	show_popup_window(_("You might want to have a look at the transfer list. "),
+			  popup_status);
+    }
+    
+    if(notify_status[NOTIFY_INJURY] == 1)
+    {
+	notify_status[NOTIFY_INJURY] = FALSE;
+	callback_notify_injury();
+    }
+
     initialize_main_window();
     status = 0;
     
     set_buttons();
-
-    if(notify_status)
-    {	
-	notify_status = FALSE;
-	show_popup_window("You might want to have a look at the transfer list. ",
-			  popup_status);
-    }
 }
 
 
@@ -462,11 +570,35 @@ on_optionmenu_figures_changed          (GtkOptionMenu   *optionmenu,
 	callback_show_history(season - 1);
 	status = 240000 + season - 1;
     }
+    else if(item == 5)
+    {
+	callback_show_graph();
+	status = -100000 - my_team * 100;
+    }
     
     set_buttons();
 }
 
 
+
+void
+on_figures_fixtures_activate           (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    on_button_fixtures_clicked(
+	GTK_BUTTON(lookup_widget(GTK_WIDGET(menuitem), "button_fixtures")), NULL);
+}
+
+
+void
+on_figures_tables_activate             (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    on_button_tables_clicked(
+	GTK_BUTTON(lookup_widget(GTK_WIDGET(menuitem), "button_tables")), NULL);
+}
+
+
 void
 on_button_league_results_clicked             (GtkButton       *button,
                                         gpointer         user_data)
@@ -481,6 +613,8 @@ void
 on_button_new_week_clicked             (GtkButton       *button,
                                         gpointer         user_data)
 {
+    GtkWidget *button_new_week =
+	lookup_widget(main_window, "button_new_week");
     gint popup_status[3] =
 	{100 + OPT_CONF_NEW_WEEK, -1, -1};
 
@@ -492,6 +626,7 @@ on_button_new_week_clicked             (GtkButton       *button,
 	   unfit_players() == 0 ||
 	   !my_team_played(week))
 	{
+	    gtk_widget_set_sensitive(GTK_WIDGET(button_new_week), FALSE);
 	    print_message("");
 	    status = 600000 + options[OPT_SHOW_MY_GAMES];
 	    callback_new_week(TRUE);
@@ -500,12 +635,12 @@ on_button_new_week_clicked             (GtkButton       *button,
 	else
 	{
 	    popup_status[0] = 100 + OPT_CONF_UNFIT;
-	    show_popup_window("There are injured or banned players in your team. Proceed?",
+	    show_popup_window(_("There are injured or banned players in your team. Proceed?"),
 			      popup_status);
 	}
     }
     else
-	show_popup_window("Are you sure you want to end this week's activities and begin a new week?",
+	show_popup_window(_("Are you sure you want to end this week's activities and begin a new week?"),
 			  popup_status);
 
     set_buttons();
@@ -528,11 +663,11 @@ on_button_stad_capacity_clicked        (GtkButton       *button,
                                         gpointer         user_data)
 {
     if(stadiums[my_team].capacity >= 100000)
-	print_message("You can't have a bigger stadium; it's not safe.");
+	print_message(_("You can't have a bigger stadium; it's not safe."));
     else if(counters[COUNT_INC_CAP] < 1)
 	show_stadium_window();
     else
-	print_message("Your stadium is being enlarged. You can't increase its capacity until work's finished.");
+	print_message(_("Your stadium is being enlarged. You can't increase its capacity until work's finished."));
 
     set_buttons();
 }
@@ -623,15 +758,9 @@ on_button_quit_clicked                 (GtkButton       *button,
 
     if(GPOINTER_TO_INT(user_data) == 1 ||
        options[OPT_CONF_QUIT] == 0 || save_status == 1)
-    {
-	free_history();
-	
-	g_string_free(save_file, TRUE);
-
 	gtk_main_quit();
-    }
     else
-	show_popup_window("Do you really want to quit without saving?", popup_status);
+	show_popup_window(_("Do you really want to quit without saving?"), popup_status);
 }
 
 void
@@ -703,14 +832,13 @@ on_start_editor_activate               (GtkMenuItem     *menuitem,
 
     if(save_status || GPOINTER_TO_INT(user_data) == 1)
     {	
-	free_history();	
-	g_string_free(save_file, TRUE);
+	free_memory();
 	gtk_widget_destroy(main_window);
 	start_editor();
 	return;
     }
 
-    show_popup_window("Your current game is not saved and will be lost. Continue?",
+    show_popup_window(_("Your current game is not saved and will be lost. Continue?"),
 		      popup_status);
 }
 
@@ -775,3 +903,81 @@ on_show_info_activate                  (GtkMenuItem     *menuitem,
     on_button_back_to_main_clicked(NULL, NULL);
     callback_show_player_info(NULL, NULL);
 }
+
+void
+on_show_statistics_activate            (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    callback_show_player_stats(NULL, NULL);
+}
+
+void
+on_shoots_penalties_activate           (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    callback_penalty_shooter();
+}
+
+
+void
+on_start_update_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    gint popup_status[3] = {93, 0, 0};
+
+    if(save_status || GPOINTER_TO_INT(user_data) == 1)
+    {	
+	free_memory();
+	start_update();
+	return;
+    }
+
+    show_popup_window(_("Your current game is not saved and will be lost. Continue?"),
+		      popup_status);
+}
+
+void
+on_optionmenu_finstad_changed          (GtkOptionMenu   *optionmenu,
+                                        gpointer         user_data)
+{
+    gint value = gtk_option_menu_get_history(optionmenu);
+
+    if(value == 1)
+    {
+	if(stadiums[my_team].capacity >= 100000)
+	    print_message(_("You can't have a bigger stadium; it's not safe."));
+	else if(counters[COUNT_INC_CAP] < 1)
+	    show_stadium_window();
+	else
+	    print_message(_("Your stadium is being enlarged. You can't increase its capacity until work's finished."));
+    }
+    else if(value == 2)
+    {
+	callback_stadium_improve();
+	show_fin_stad();
+    }
+    else if(value == 3)
+    {
+	if(callback_get_loan() == 1)
+	    status = 310000;
+    }
+    else if(value == 4)
+    {
+	if(callback_pay_loan() == 1)
+	    status = 320000;
+    }
+
+    gtk_option_menu_set_history(optionmenu, 0);
+
+    set_buttons();
+}
+
+void
+on_checkbutton_boost_toggled           (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+    options[OPT_BOOST] = 
+	gtk_toggle_button_get_active(togglebutton);
+
+    bookmaker_re_tip();
+}
