@@ -2,11 +2,22 @@
  * Support functions for the callback functions in 'editor_callbacks.c'  *
  *************************************************************************/
 
-#include "defs.h"
 #include "editor_defs.h"
+#include "callback_func.h"
+#include "editor_callback_func.h"
+#include "gui.h"
+#include "maths.h"
+#include "misc.h"
+#include "player.h"
+#include "startup.h"
 #include "support.h"
+#include "team.h"
+#include "files.h"
+#include "treeview.h"
+#include "window.h"
 
-void set_spinbutton_values(void)
+void
+set_spinbutton_values(void)
 {
     GtkWidget *entry_name =
 	lookup_widget(main_window, "entry_name");
@@ -47,7 +58,8 @@ void set_spinbutton_values(void)
     label_set_text_from_int(GTK_LABEL(label_number), selected_player + 1, 0);
 }
 
-void write_average_skill(void)
+void
+write_average_skill(void)
 {
     GtkWidget *spinbutton_average_skill =
 	lookup_widget(main_window, "spinbutton_average_skill");
@@ -56,7 +68,8 @@ void write_average_skill(void)
 			      average_skill(114, 20, FALSE));
 }
 
-void write_team_to_screen(void)
+void
+write_team_to_screen(void)
 {
     gint i;
     GtkWidget *entry_structure1 =
@@ -69,7 +82,7 @@ void write_team_to_screen(void)
     GtkTreeSelection *selection =
 	gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview_players));
     GtkTreePath *path;
-    gchar buf[BUF_SIZE_SMALL];
+    gchar buf[SMALL];
     gint attrib[ATT_END];
     gint ids[20][2];
     gfloat adjust_factor = 0.5;
@@ -117,9 +130,10 @@ void write_team_to_screen(void)
     gtk_tree_selection_select_path(selection, path);
 }
 
-void callback_change_structures(void)
+void
+callback_change_structures(void)
 {
-    gchar buf[BUF_SIZE_SMALL];
+    gchar buf[SMALL];
     GtkWidget *entry_structure1 =
 	lookup_widget(main_window, "entry_structure1");
     GtkWidget *entry_structure2 =
@@ -132,7 +146,7 @@ void callback_change_structures(void)
        get_place(local_structure2, 1) + get_place(local_structure2, 2) + 
        get_place(local_structure2, 3) != 8)
     {
-	sprintf(buf, "One of the structure numbers is not a valid structure specifier. The digits of the first structure must add up to 10, those of the second one to 8. ");
+	sprintf(buf, _("One of the structure numbers is not a valid structure specifier. The digits of the first structure must add up to 10, those of the second one to 8. "));
 	show_popup_window(buf, NULL);
 	return;
     }
@@ -143,18 +157,19 @@ void callback_change_structures(void)
     write_team_to_screen();
 }
 
-void set_teams_file_pulldown(void)
+void
+set_teams_file_pulldown(void)
 {
     GtkWidget *combo_team_file =
 	lookup_widget(main_window, "combo_team_file");
     GList *league_files = NULL;
-    gchar filenames[TEXT_FILES_PLAYER_NAMES][BUF_SIZE_SMALL];
+    gchar filenames[FILES_PLAYER_NAMES][SMALL];
     gint i;
     
-    for(i=0;i<TEXT_FILES_PLAYER_NAMES;i++)
+    for(i=0;i<FILES_PLAYER_NAMES;i++)
 	text_file_number_to_char(i, filenames[i], TRUE);
 
-    for(i=0;i<TEXT_FILES_PLAYER_NAMES;i++)
+    for(i=0;i<FILES_PLAYER_NAMES;i++)
 	if(strcmp(filenames[i], "") != 0)
 	    league_files = g_list_append(league_files, filenames[i]);
 
@@ -164,7 +179,8 @@ void set_teams_file_pulldown(void)
     g_list_free(league_files);
 }
 
-void callback_load_team_file(void)
+void
+callback_load_team_file(void)
 {
     GtkWidget *entry_country_file =
 	lookup_widget(main_window, "entry_country_file");
@@ -173,21 +189,15 @@ void callback_load_team_file(void)
     const gchar *entry_text = gtk_entry_get_text(GTK_ENTRY(entry_country_file));
     gchar *filename;
     FILE *fil;
-    gchar buf[BUF_SIZE_SMALL];
     gchar team_names[500][50];
     gint i;
     GList *country_list = NULL;
 
     filename = g_malloc(strlen(entry_text) + 1);
     strcpy(filename, entry_text);
-    fil = fopen(filename, "r");	
     
-    if(fil == NULL)
-    {
-	sprintf(buf, "Could not open file: %s .", filename);
-	show_popup_window(buf, NULL);
+    if(!my_fopen(filename, "r", &fil, FALSE))
 	return;
-    }
 
     fclose(fil);
 
@@ -209,7 +219,8 @@ void callback_load_team_file(void)
     g_free(filename);
 }
 
-void callback_load_team(void)
+void
+callback_load_team(void)
 {
     GtkWidget *entry_team_name =
 	lookup_widget(main_window, "entry_team_name");
@@ -220,24 +231,19 @@ void callback_load_team(void)
     GtkWidget *entry_definitions_file =
 	lookup_widget(main_window, "entry_definitions_file");
     const gchar *def_file = gtk_entry_get_text(GTK_ENTRY(entry_definitions_file));
-    FILE *fil = fopen(def_file, "r");
-    gchar buf[BUF_SIZE_SMALL];
+    FILE *fil;
+    gchar buf[SMALL];
     gint i;
 
     if(strcmp(team_name, "") == 0 || strcmp(def_file, "") == 0)
     {
-	sprintf(buf, "You haven't selected a team you want to edit or a definitions file. ");
+	sprintf(buf, _("You haven't selected a team you want to edit or a definitions file. "));
 	show_popup_window(buf, NULL);
 	return;	
     }
 
-    if(fil == NULL)
-    {
-	sprintf(buf, "The file %s could not be opened.",
-		def_file);
-	show_popup_window(buf, NULL);
+    if(!my_fopen(def_file, "r", &fil, FALSE))
 	return;
-    }
 
     fclose(fil);
 
@@ -266,7 +272,8 @@ void callback_load_team(void)
 
 /* save the name of the edited team to
    the country file */
-void save_team_name(void)
+void
+save_team_name(void)
 {
     GtkWidget *entry_country_file =
 	lookup_widget(main_window, "entry_country_file");
@@ -282,26 +289,19 @@ void save_team_name(void)
 	gtk_entry_get_text(GTK_ENTRY(entry_country_file));
     FILE *fil;
     GString *file_content;
-    gchar buf[BUF_SIZE_BIG];
+    gchar buf[BIG];
 
     if(strcmp(team_name, new_name) == 0)
 	return;
 
     if(strlen(new_name) == 0)
     {
-	show_popup_window("You haven't entered a new team name. ", NULL);
+	show_popup_window(_("You haven't entered a new team name. "), NULL);
 	return;
     }
     
-    fil = fopen(country_file, "r");
-    if(fil == NULL)
-    {
-	sprintf(buf,
-		"Could not open file: %s. The new team name could not be saved.",
-		country_file);
-	show_popup_window(buf, NULL);
+    if(!my_fopen(country_file, "r", &fil, FALSE))
 	return;
-    }
     
     file_content = g_string_new("");
     strcpy(buf, "");
@@ -321,7 +321,7 @@ void save_team_name(void)
     if(strcmp(buf, "1000") == 0 ||
        feof(fil) != 0)
     {
-	show_popup_window("Could not save new team name to %s. I couldn't find the old name.",
+	show_popup_window(_("Could not save new team name to %s. I couldn't find the old name."),
 			  NULL);
 	g_string_free(file_content, TRUE);
 	return;
@@ -348,10 +348,11 @@ void save_team_name(void)
 
 /* save currently edited team to the
    defs file or alternatively to the argument file */
-void save_defs(const gchar *def_file)
+void
+save_defs(const gchar *def_file)
 {
     gint i, skill, talent;
-    gchar buf[BUF_SIZE_SMALL];
+    gchar buf[SMALL];
     gchar player_name[19];
     GtkWidget *entry_team_name =
 	lookup_widget(main_window, "entry_team_name");
@@ -434,12 +435,12 @@ void save_defs(const gchar *def_file)
     fclose(fil);
 
     if(talent_error)
-	show_popup_window("One or more players could not be saved because of an invalid talent value. The talent value of a players has to be greater or equal his skill value. ", NULL);
+	show_popup_window(_("One or more players could not be saved because of an invalid talent value. The talent value of a players has to be greater or equal his skill value. "), NULL);
 }
 
-gboolean callback_save_defs(void)
+gboolean
+callback_save_defs(void)
 {
-    gchar buf[BUF_SIZE_SMALL];
     GtkWidget *entry_team = 
 	lookup_widget(main_window, "entry_team");
     const gchar *team_name =
@@ -451,18 +452,12 @@ gboolean callback_save_defs(void)
 
     if(strcmp(team_name, "") == 0)
     {
-	show_popup_window( "You haven't selected a team. ", NULL);
+	show_popup_window( _("You haven't selected a team. "), NULL);
 	return FALSE;	
     }
 
-    fil = fopen(def_file, "a+");
-    if(fil == NULL)
-    {
-	sprintf(buf, "The file %s could not be opened in read/write mode.",
-		def_file);
-	show_popup_window(buf, NULL);
+    if(!my_fopen(def_file, "a+", &fil, FALSE))
 	return FALSE;
-    }
 
     fclose(fil);
     save_defs(def_file);
@@ -470,7 +465,8 @@ gboolean callback_save_defs(void)
     return TRUE;
 }
 
-void callback_swap_players(void)
+void
+callback_swap_players(void)
 {
     GtkWidget *spinbutton_swap1 =
 	lookup_widget(main_window, "spinbutton_swap1");
@@ -492,7 +488,8 @@ void callback_swap_players(void)
     write_team_to_screen();
 }
 
-void callback_play(gint save)
+void
+callback_play(gint save)
 {
     if(save == 1)
 	if(!callback_save_defs())
@@ -506,11 +503,12 @@ void callback_play(gint save)
     start(0);
 }
 
-void callback_edit_player(GtkTreeSelection *selection,
+void
+callback_edit_player(GtkTreeSelection *selection,
 			  GdkEventButton *event)
 {   
     gint selected = 
-	get_row_index(selection, event) - 1;
+	get_row_index(selection, event, 0) - 1;
 
     if(selected < 0)
 	return;
@@ -522,7 +520,8 @@ void callback_edit_player(GtkTreeSelection *selection,
     write_team_to_screen();
 }
 
-void callback_update(void)
+void
+callback_update(void)
 {
     GtkWidget *entry_name =
 	lookup_widget(main_window, "entry_name");
@@ -550,16 +549,16 @@ void callback_update(void)
     
     if(new_skill > new_talent)
     {
-	show_popup_window("You have entered an invalid talent value. The talent value of a player has to be greater than his skill value. ", NULL);
+	show_popup_window(_("You have entered an invalid talent value. The talent value of a player has to be greater than his skill value. "), NULL);
 	return;
     }
 
     if(new_name[0] == '#')
-	show_popup_window("You have entered a player name beginning with the comment character '#'. The player will be ignored when loading the team from the definitions file. ", NULL);
+	show_popup_window(_("You have entered a player name beginning with the comment character '#'. The player will be ignored when loading the team from the definitions file. "), NULL);
     
     if(new_age < 17)
     {
-	show_popup_window("You have entered an invalid birth date. Players must be older than 17. ", NULL);
+	show_popup_window(_("You have entered an invalid birth date. Players must be older than 17. "), NULL);
 	return;
     }
 
@@ -573,7 +572,8 @@ void callback_update(void)
     write_team_to_screen();
 }
 
-void callback_move(gint direction)
+void
+callback_move(gint direction)
 {
     gint new_number = selected_player + direction;
 
@@ -597,7 +597,8 @@ void callback_move(gint direction)
 }
 
 /* select next or previous player in the list */
-void callback_change_player(gint direction)
+void
+callback_change_player(gint direction)
 {
     selected_player += direction;
 
@@ -611,7 +612,8 @@ void callback_change_player(gint direction)
     write_team_to_screen();
 }
 
-void callback_change_average_skill(void)
+void
+callback_change_average_skill(void)
 {
     gint i;
     gfloat current_average = average_skill(114, 20, FALSE);
@@ -634,12 +636,13 @@ void callback_change_average_skill(void)
 
 /* extend the team definitions file by the contents
    of another team file */
-void import_file(const gchar *file_name)
+void
+import_file(const gchar *file_name)
 {
     GtkWidget *entry_definitions_file =
 	lookup_widget(main_window, "entry_definitions_file");
     const gchar *def_file = gtk_entry_get_text(GTK_ENTRY(entry_definitions_file));
-    gchar buf[BUF_SIZE_BIG];
+    gchar buf[BIG];
     GString *imported_teams = g_string_new("");
     FILE *definitions_file;
     FILE *import_file;
@@ -654,14 +657,12 @@ void import_file(const gchar *file_name)
     definitions_file = fopen(def_file, "a");
     import_file = fopen(file_name, "r");
 
-    if(definitions_file == NULL || import_file == NULL)
-    {
-	show_popup_window("One of the files could not be opened. ", NULL);
+    if(!my_fopen(def_file, "a", &definitions_file, FALSE) ||
+       !my_fopen(file_name, "a", &import_file, FALSE))
 	return;
-    }
 
     g_string_append_printf(imported_teams, 
-			   "The following teams were added to %s:\n\n", def_file);
+			   _("The following teams were added to %s:\n\n"), def_file);
 
     while(feof(import_file) == 0)
     {
@@ -697,7 +698,7 @@ void import_file(const gchar *file_name)
     fclose(definitions_file);
 
     if(no_imports)
-	g_string_append_printf(imported_teams, "NONE\n");
+	g_string_append_printf(imported_teams, _("NONE\n"));
     
     show_popup_window(imported_teams->str, NULL);
 
